@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -166,6 +166,14 @@ public class CopyTools {
         }
     }
 
+    public static void setBinaryOrNull(int parameter, PreparedStatement stmt, byte[] value) throws SQLException {
+        if (value == null) {
+            stmt.setNull(parameter, java.sql.Types.BINARY);
+        } else {
+            stmt.setBytes(parameter, value);
+        }
+    }
+
     public static void setIntOrNull(final int parameter, final PreparedStatement stmt, final int value) throws SQLException {
         if (value == -1) {
             stmt.setNull(parameter, java.sql.Types.VARCHAR);
